Everything required to define an observer inside a 3d world. This object holds the projection matrix and its associated frustum as well as the transformation of the observer.

The world content is transformed by the observer view matrix before being projected to screen using its projection matrix.